Top

    Praxis Seizure: Leiria
    Leiria, Portugal
    October 13th 2012
    2R+F
    12 players
    Patrick Gordo

    Deck Name: Shadowfang

    Crypt (12 cards, min=18, max=24, avg=5.5)
    -----------------------------------------
    3x Morel		6   AUS DEM OBF			  Malkavian:4
    2x Gem Ghastly		6   DEM OBF aus		primogen  Malkavian:5
    2x Hagar Stone		6   AUS DEM obf			  Malkavian antitribu:5
    2x Arthur Denholm	5   AUS DEM obf			  Malkavian:5
    1x Drusilla Euphemia	6   AUS OBF dem vic		  Malkavian antitribu:4
    1x Apache Jones		5   DEM aus for obf		  Malkavian antitribu:4
    1x Bela			3   DEM ani obf pro		  Malkavian:5

    Master (11)
    1 Barrens, The
    1 Blood Doll
    2 Dreams of the Sphinx
    1 Giant's Blood
    1 Pentex(TM) Subversion
    3 Sudden Reversal
    2 Vessel

    Action (17)
    16 Kindred Spirits Dementation
    1 Restructure Dementation

    Action Modifier (31)
    3 Cloak the Gathering Obfuscate
    8 Confusion Dementation
    3 Elder Impersonation Obfuscate
    7 Eyes of Chaos Dementation
    2 Faceless Night Obfuscate
    3 Lost in Crowds Obfuscate
    5 Spying Mission Obfuscate

    Action Modifier/Combat (7)
    3 Deny Dementation
    4 Swallowed by the Night Obfuscate

    Reaction (15)
    2 Delaying Tactics
    3 My Enemy's Enemy Auspex
    3 On the Qui Vive
    5 Telepathic Misdirection Auspex
    2 Wake with Evening's Freshness